% 
% This script launches the program for the MonteCarlo solution of
% Jin-Xin relaxation system for a scalar conservation law, comparing
% it with a second order finite volume scheme for the relaxation
% system
%
clear all
n=80; % number of space cells
np=20000 % total number of particles
%
% Initial condition, flux function and characteristic speed
%
f = inline('0.5*u.^2'); % flux function
%f = inline('-2*u'); % flux function
%u0=inline('1+0.5*sin(pi*x)');
%u0=inline('0.5+0.4*sin(pi*x)');
u0=inline('0.25.*(2+sin(2*pi*x) - sin(pi*x))');
a=1;
ab=[-1,1]; T=3;
h=(ab(2)-ab(1))/n; % Mesh spacing
epsi=1.e-3;
%
% Set up the initial conditions for the MC solver
%
[u_mc,celle,particelle,xb,du]=init(n,np,ab,f,u0,a);
%
% Set up the grid and the initial conditions for the FV solver
%
fisico=3:n+2;  % Computational indices
x(fisico)=(ab(1)+h/2):h:(ab(2)-h/2);
x(1) = x(fisico(1))-2*h;
x(2) = x(fisico(1))-h;
x(fisico(n)+2) = x(fisico(n))+2*h;
x(fisico(n)+1) = x(fisico(n))+h;
dt = 0.9*h/a; 
lambda=dt/h;
nt=fix(T/dt+0.5); 
dt=T/nt;
%
fprintf('Total number of particles %7.0f \n',np)
fprintf('Mass of each particle %12.4g \n',du)
fprintf('Relaxation time %6.3f \n', dt/epsi)
fprintf('Equilibrium fraction %6.3f \n', 1-exp(-dt/epsi))
[u_fv,v_fv,r,rinv]=jinxin_init(x,fisico,h,u0,f,a);
u_fv=bc(u_fv,fisico);
v_fv=bc(v_fv,fisico);
%dt=h;
left=[]; right=[];
%nt=2
for kt=1:nt
  particelle1=rilassa(celle,u_mc,particelle,f,a,dt,epsi);
  [particelle,celle,jxoutl,jxoutr]=trasporta(celle,u_mc,particelle1,xb,dt);
  u_mc=costruisci(celle,du,h);
%
% Perform two time steps with the FV solver, so that lambda is lambda/2
  [u_fv,v_fv]=jinxin_step(f,u_fv,v_fv,fisico,lambda/2,a,h,dt,epsi,r,rinv);
  [u_fv,v_fv]=jinxin_step(f,u_fv,v_fv,fisico,lambda/2,a,h,dt,epsi,r,rinv);

  figure(4)
  plot(x(fisico),u_mc,'kx')
  axis([-1 1 -0.2 1.2])
  hold on
  plot(x(fisico),u_fv(fisico),'g')
  hold off
end