function [u,celle,particelle,xb,du]=init(n,np,ab,f,u0,a)
% [u,celle,particelle,a,xb] creates the initial condition (solution U and
%  PARTICELLE) for a  Monte Carlo  method applied to Jin-Xin relaxation system
%  NP = total number of particles
%  U = solution
%  CELLE = structure containing the address of each particle
%  XB = cell edges

%
% Set up:
%
% mesh width h
h=(ab(2)-ab(1))/n;
fisico=1:n;
%
x(1:n)=ab(1)+h/2:h:ab(2)-h/2; % cell centers
xb(1:n+1)=ab(1):h:ab(2); % cell edges
% Compute the cell averages of the initial condition
for j=fisico
  u(j)=quad(u0,xb(j),xb(j+1))/h;
end
%
% Compute particles setting up the index structure
%
%  particelle(j,1) ----> position
%  particelle(j,2) ----> microscopic velocity
%
%  celle(j).number ----> number of particles in the j-th cell
%  celle(j).i ----> indices of particles in the j-th cell
%
total_u=sum(u(fisico))*h;
du=total_u/np;
nj(fisico)=fix(u(fisico)*h/du+0.5); %np=sum(nj);
u(fisico)=du*nj(fisico)/h;
rj=rand(np,2);
jj=0;
fu(fisico) = feval(f,u(fisico));
for j=fisico
  fj = (a*u(j) + f(u(j)) )/(2*a);
  p1 = fj/u(j);
  particelle(jj+1:jj+nj(j), 1) = x(j)-h/2+rj(jj+1:jj+nj(j),1)*h;
  particelle(jj+1:jj+nj(j), 2) = 2*a*(rj(jj+1:jj+nj(j),2) < p1) -a;
  celle(j).number=nj(j);
  celle(j).i=jj+1:jj+nj(j);
  jj=jj+nj(j); 
end 
