function [u1,v1]=jinxin_step(f,u,v,fisico,lambda,a,h,dt,epsi,r,rinv)
% 
% Advance one step the solution of jin_xin scheme using a second order IMEX
% scheme
%
gama=1-1/sqrt(2);
coeff=gama*dt/epsi;
coeff2=(1-2*gama)*dt/epsi;
alambda=a*lambda;
%
% Relaxation step
u1(fisico) = u(fisico); 
f1(fisico)=feval(f,u1(fisico));
v1(fisico) = (v(fisico) + coeff*f1(fisico))/(1+coeff);
u1=bc(u1,fisico);
v1=bc(v1,fisico);
%
% Convection step
% compute characteristic variables
uc=rinv(1,:)*[u1; v1];
vc=rinv(2,:)*[u1; v1];
% compute the numerical flux
[fleft1,gright1]=jinxin_flux(uc,vc,fisico);
utemp(fisico)=u(fisico)-alambda*(fleft1(fisico)-fleft1(fisico-1) - ...
              gright1(fisico)+gright1(fisico-1));
vtemp(fisico)=v(fisico)-alambda*a*(fleft1(fisico)-fleft1(fisico-1) + ...
              gright1(fisico)-gright1(fisico-1));
v2(fisico)=vtemp(fisico) + coeff2*(f1(fisico) - v1(fisico));
%
% Second relaxation step
u2 = utemp; 
v2 = (v2 + coeff*feval(f,u2))/(1+coeff);
u2=bc(u2,fisico);
v2=bc(v2,fisico);
%
% Convective flux for [u2,v2]:
uc=rinv(1,:)*[u2; v2];
vc=rinv(2,:)*[u2; v2];
[fleft2,gright2]=jinxin_flux(uc,vc,fisico);
% Assemble the convective part of the RK scheme
utemp(fisico)=u(fisico)-alambda/2*(fleft1(fisico)-fleft1(fisico-1) - ...
              gright1(fisico)+gright1(fisico-1));
vtemp(fisico)=v(fisico)-alambda/2*a*(fleft1(fisico)-fleft1(fisico-1) + ...
              gright1(fisico)-gright1(fisico-1));
utemp(fisico)=utemp(fisico)-alambda/2*(fleft2(fisico)-fleft2(fisico-1) - ...
              gright2(fisico)+gright2(fisico-1));
vtemp(fisico)=vtemp(fisico)-alambda/2*a*(fleft1(fisico)-fleft1(fisico-1) + ...
              gright2(fisico)-gright2(fisico-1));
% Add the source term:
u1(fisico)=utemp(fisico);
v1(fisico)=vtemp(fisico)+dt/(2*epsi)*(f1(fisico) + feval(f,u2(fisico))  ...
                   -v2(fisico)-v1(fisico) );
u1=bc(u1,fisico);
v1=bc(v1,fisico);
